pro comp_day, year, bmon, emon

; daily rain plot for co-located gauges 

close,/all

;year='2014'
;month='08'
nid=12  ; gauge ID: 1-12


for imon=bmon*1,emon*1 do begin

month=string(imon,format='(i02)')

;print, 'Plotting Daily Rainfall ('+month+'/01 -'+ month+'/'+yday+')'
days_in_mon,year,month,nday

rain=fltarr(nid+1,nday+1)
gname=strarr(nid+1)
gag_dir="GAG_QCed/" + year+"/"
comp_dir="COMP/day/"+year+"/"
if(file_test(comp_dir,/directory) ne 1) then file_mkdir,comp_dir
line='' 
yr=0 & mon=0 & day=0 & jday=0 & hr=0 & mn=0 & sec=0

for id=1,nid do begin
    sid=string(id,format='(i02)')
    rain[id,*]=0.

    infile=gag_dir+'WFF00'+sid+'_*'+year+'.gag'
    if(file_test(infile) eq 0) then begin
        rain[id,*]=-9.99 
        gname[id]='Missing'
        goto, next_id
    endif

    openr,1,infile
    readf, 1,line
    a=strsplit(line,/extract)
    gname[id]=a[3]
    readf, 1,line
    while(not eof(1)) do begin
        readf,1,format='(i4,2x,i2,2x,i2,2x,i3,i3,2i4,f7.3)',yr,mon,day,jday,hr,mn,sec,tp 
        if(month*1 ne mon) then goto,next_rec 
        rain[id,day]=rain[id,day]+tp ;mm
          ;print,format='(3i4,i5,3i4,f7.3)',yr,mon,day,jday,hr,min,sec,tp
        next_rec: 
    endwhile
    close,1
    
    next_id:
endfor
    

outfile=comp_dir+"WFF_"+year+"-"+month+".day.txt"
openw,6,outfile
printf,6,indgen(nid)+1, format='("Day", 12(" WFF",i04) )'
for iday=1,nday do begin
    printf,6,format='(1x,i2.2,12f8.3)',iday,rain[1:12,iday]
endfor
close,6


set_plot, 'Z', /COPY
device, set_resolution=[1100,800] 
loadct,39

tl='Daily Rainfall from NASA WFF gauges'
limit=max(rain)*1.1
if limit lt 40 then limit=40
xv=indgen(nday)+1
day=strtrim(string(indgen(nday)+1),2)
plot,[1,nday],[0,limit],thick=2,charsize=1.5, xticks=nday-1, $
  xtitle='Day of '+year+'-'+month, xtickname=day,xtickv=xv,  $
  subtitle=tl,ytitle='Rainfall [mm]',linestyle=0,/xstyle,/YSTYLE, $
  ymargin=[6,4],/NODATA, color=1,background=255


for id=1,nid do begin
    if(gname[id] ne 'Missing') then $    
      oplot,rain[id,*], thick=3,color=id*20, linestyle=id-1, min_value=0      
    sid=string(id,format='(i02)')
    hh=(limit*0.6)/12*id+10
    xx=6 & dt=2 & dh=2
    if year eq '2014' and month eq '06' then xx=22
    if year eq '2014' and month eq '09' then xx=13
    plots,[xx,xx+dt],hh+0.5,thick=3,color=id*20,linestyle=id-1 ;legend for gauge 
    xyouts,xx+dt,hh,charsize=1.2," WFF00"+sid+'('+gname[id]+')',color=id*20

endfor

; ------ put the figures as png files -----------------------------
pngfile=comp_dir+"WFF_"+year+"-"+month+".day.png"
pngit,pngfile, 2


device,/close

endfor   ; month




end
