pro qc_gag, gagfile, qcgagfile, res, qc_threshold

;####################################################################
;##  QC gag data entries                                           ##
;##  Discard bad data and test tip in gag files                    ##
;##                                                                ##
;##      Sort the data, then                                       ## 
;##      Auto QC to remove                                         ##
;##      (1) redudant entries or multiple tips in 1 sec            ##
;##            (keep 1st entry)                                    ##
;##      (2) test tips or 1 tip every second                       ##
;##      (3) entries  if ave # of tips in one minute >= 40         ##
;##         (rainrate >40*0.254 mm/min during the minute )         ##
;##      (4) multiple tips in one record (rainrate>=2*0.254*60/min)##
;####################################################################


;res=0.254     ; 0.01" for all WFF gauges
;qc_threshold=10.15   ; remove data if >= 40 tip/min 
;gagfile="GAG/2013/WFF0009_PITA_2013.gag"


    nm=366L*24*60
    lines=strarr(nm)
    qclines=strarr(nm) 
    rain=fltarr(nm)
    duration=intarr(nm)

    print, 'QCing '+gagfile

    a=strsplit(gagfile,'/',/extract)
    yyyy=a[1]
    gag_qc_dir='GAG_QCed/'+yyyy+'/'
    if (file_test(gag_qc_dir,/directory ) eq 0) then file_mkdir, gag_qc_dir
 
   ; sort_data,gagfile

    openr,lun_gag,gagfile,/get_lun
    qcgagfile=gag_qc_dir+a[2]
   ; gauge=strmid(a[2],0,10)

    openw,lun_qcgag,qcgagfile,/get_lun
    line=''
    header1=''  & header2=''  
    dhm0='0000000'

    readf,lun_gag,header1
    readf,lun_gag,header2
    printf,lun_qcgag, header1
    printf,lun_qcgag, header2

    i=0L 
    while(not eof(lun_gag)) do begin
        readf,lun_gag,line
        lines[i]=line
        qclines[i]=line
        a=strsplit(lines[i],/extract)
        jday=a[3]
        hr=a[4]
        min=a[5]
        sec=long(a[6]*1.)
        tip=a[7]*1.
        	
        time=sec+(min*1+hr*60+(jday-1)*24L*60)*60  ; seconds 
        dhm=jday+hr+min
        if(dhm ne dhm0) then sec0=sec ;1st second in current minute

        if(i gt 0) then begin
            if( fix(time-time0) eq 0) then begin
                ; print, ' keep 1st entry in 1-sec duration: '+lines[i]
                qclines[i]    = lines[i]   + ' ?'
                tip=0 
            endif
        endif
      
        time0=time
        time_m=time/60 
        duration[time_m]=sec-sec0+1 
        rain[time_m]=rain[time_m]+tip        
  
        dhm0=dhm
        i++ 
    endwhile
    free_lun,lun_gag

    for j=0,i-1 do begin

        a=strsplit(qclines[j],/extract, count=cc)
        mon=a[1]
        mday=a[2]
        jday=a[3]
        hr=a[4]
        min=a[5]
        hhmm=hr+min
        mmdd=mon+mday

;----- Auto QC  -------------------------------- 
        ;print, qclines[j]
        if(cc eq 11) then begin
            ;print,  '  removed '+qclines[j]
            goto,nextline
        endif 

      	time=min*1+hr*60+(jday-1)*24L*60
        rainrate=60.*rain[time]/duration[time]   

        if( (rainrate gt qc_threshold and duration[time] gt 1) or $
            (rainrate gt 30.4 and duration[time] eq 1) ) then begin
             print, "  removed bad: "+qclines[j]
        endif else begin
            ;remove decimal places for field of "second".
            ;p=strpos(qclines[j] ,'.')
            ;newline=strmid(qclines[j],0,p)+strmid(qclines[j],p+5)           
            printf,lun_qcgag,   qclines[j]     
        endelse

        nextline:
        
    endfor

    free_lun,lun_qcgag
      

    end

